#
# spec file for package vigra
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _shlibname libvigraimpex5
Name:           vigra
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
%if 0%{?suse_version} >= 1220
BuildRequires:  hdf5-devel
%endif
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
%if 0%{?suse_version} > 1220
BuildRequires:  openexr-devel
%endif
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  zlib-devel
Summary:        Computer vision Library
License:        MIT
Group:          Development/Libraries/C and C++
Version:        1.10.0
Release:        6.3
Source:         https://github.com/ukoethe/vigra/releases/download/Version-1-10-0/vigra-1.10.0-src-with-docu.tar.gz
Url:            http://ukoethe.github.io/vigra/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
VIGRA stands for "Vision with Generic Algorithms". It is a novel
computer vision library that puts its main emphasis on customizable
algorithms and data structures. By using template techniques similar to
those in the C++ Standard Template Library, you can easily adapt any
VIGRA component to the needs of your application, without giving up
execution speed.

%package -n %{_shlibname}
Summary:        Computer vision Library
Group:          Development/Libraries/C and C++
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n %{_shlibname}
VIGRA stands for "Vision with Generic Algorithms". It is a novel
computer vision library that puts its main emphasis on customizable
algorithms and data structures. By using template techniques similar to
those in the C++ Standard Template Library, you can easily adapt any
VIGRA component to the needs of your application, without giving up
execution speed.

%package devel
Summary:        Development files for VIGRA Library
Group:          Development/Libraries/C and C++
Requires:       %{_shlibname} = %{version}
Requires:       fftw3-devel
%if 0%{?suse_version} >= 1220
Requires:       hdf5-devel
%endif
Requires:       libjpeg-devel
Requires:       libpng-devel
Requires:       libstdc++-devel
Requires:       libtiff-devel
%if 0%{?suse_version} > 1220
Requires:       openexr-devel
%endif
Requires:       zlib-devel

%description devel
VIGRA stands for "Vision with Generic Algorithms". It is a novel
computer vision library that puts its main emphasis on customizable
algorithms and data structures. By using template techniques similar to
those in the C++ Standard Template Library, you can easily adapt any
VIGRA component to the needs of your application, without giving up
execution speed.

%prep
%setup -q

%build
mkdir build
cd build
cmake -DCMAKE_INSTALL_PREFIX=%{_prefix} \
      -DDOCINSTALL=%{_docdir} \
      -DWITH_HDF5=1 \
%if %{_lib} == "lib64"
      -DLIBDIR_SUFFIX=64 \
      -DLIB_SUFFIX=64 \
%endif
%if 0%{?suse_version} > 1220
      -DWITH_OPENEXR=1 \
%endif
      ..

make %{?_smp_mflags}

%install
cd build
%makeinstall

rm -rf %{buildroot}%{_docdir}/vigranumpy

%post -n %{_shlibname} -p /sbin/ldconfig

%postun -n %{_shlibname} -p /sbin/ldconfig

%files -n %{_shlibname}
%defattr(-,root,root)
%doc README.md LICENSE.txt
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%{_bindir}/vigra-config
%{_libdir}/*.so
%{_includedir}/*
%dir %{_libdir}/vigra/
%{_libdir}/vigra/*.cmake
%doc %{_docdir}/%{name}

%changelog
* Tue Jan  7 2014 speilicke@suse.com
- Fix source URL
* Fri Jan  3 2014 adrian@suse.de
- update to version 1.10.0
  * see http://ukoethe.github.io/vigra/doc-release/vigra/CreditsChangelog.html
  * comes with tutorial as part of documentation now
- so name bump to version 5
- fixing baselibs config
* Tue Jun  4 2013 tchvatal@suse.com
- Version bump to 1.9.0
  * see http://hci.iwr.uni-heidelberg.de/vigra/doc/vigra/CreditsChangelog.html
- Update openexr finding and libdir target.
* Tue Sep 18 2012 idonmez@suse.com
- Update to version 1.8.0
  * See http://hci.iwr.uni-heidelberg.de/vigra/doc/vigra/CreditsChangelog.html
- Drop all the patches, fixed upstream.
- Fixed dependencies for the devel package.
* Thu Sep  6 2012 pgajdos@suse.com
- build also against libpng15
  * libpng15.patch
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Apr 24 2011 toddrme2178@gmail.com
- Add 32bit compatibility libraries
- Remove test for obsolete openSUSE versions
- Made package no longer obsolete itself (fix for RPMLINT warning)
- More informative summaries (fix for RPMLINT warning)
* Thu Dec  9 2010 cristian.rodriguez@opensuse.org
- Fix -devel package dependencies
* Thu Apr  8 2010 pgajdos@suse.cz
- fixed build with libpng14
* Thu Apr 23 2009 sbrabec@suse.cz
- Don't call autoreconf on older products.
* Mon Mar  2 2009 crrodriguez@suse.de
- save 3.8MB by removing static libraries and "la" files
* Tue Oct 14 2008 sbrabec@suse.cz
- Fix acinclude.m4 to allow autoreconf to prevent build failure.
* Thu Sep  4 2008 sbrabec@suse.cz
- Updated to version 1.6.0:
  * Added functions for arrays of arbitrary dimensions.
  * Added functionality for 3D image analysis.
  * Added Random Number Generation.
  * Functions for affine transformation matrices.
  * Added linear algebra functionality.
  * Extended handling of rectangular matrices.
  * Extended matrix functionality.
  * Added sRGB to Color Space Conversions
  * Other improvements and bug fixes in the code and documentation.
* Sun Jul 29 2007 ro@suse.de
- provide and obsolete old name
* Thu Jul 26 2007 sbrabec@suse.cz
- Updated to version 1.5.0:
  * minor fixes
  * several functions added
  * documentation update
- Rename package according to shared library packaging policy.
* Fri Apr 20 2007 aj@suse.de
- Remove unneeded build requires.
* Mon Jul 17 2006 nadvornik@suse.cz
- do not redefine _AC_INIT_HELP in acinclude.m4
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 sbrabec@suse.cz
- Updated to version 1.4.0.
- Split devel subpackage.
* Mon Feb 14 2005 mcihar@suse.cz
- update to 1.3.2
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Mon Oct 25 2004 ro@suse.de
- create directory config before use
* Tue Aug  3 2004 mcihar@suse.cz
- regenerate configure scripts to know all architectures
- fix compilation on 64-bit platforms
* Fri Jul 30 2004 mcihar@suse.cz
- initial packaging
